# multinet library (python version)

This repository contains the python version of the _multinet_ library for the analysis of multilayer networks, first released for the R framework in January 2017 on CRAN.

The library is available on PyPI (the Python Package Index), and can be installed using _pip_. This repository is mainly useful if you want to develop the library.

This library was originally based on the book: Multilayer Social Networks, by Dickison, Magnani & Rossi, Cambridge University Press (2016). The methods contained in the library and described in the book have been developed by many different authors: extensive references are available in the book, and in the documentation of each function we indicate the main reference we have followed for the implementation. For some methods developed after the book was published we give references to the corresponding literature. Additional information, including material such as survey articles and datasets, is available at http://multilayer.it.uu.se/.

## Requirements

* python >= 3.8

## Installation

    pip install uunet

(this provides the module: uunet.multinet)

## Usage

In the directory `tutorial/` you find example code covering most of the functions in the library. Documentation
for all functions can be obtained from Python using `help()`.

## Contact

For any inquiries regarding this repository you can contact <matteo.magnani@it.uu.se>.
